
------------------------------------------------------------------------
--  IBM*                                                                  
--  Licensed Materials - Property of IBM                                  
--  5765-F38                                                              
--  (C) Copyright IBM Corporation 2001,2003                               
--  All rights reserved.                                                  
--                                                                        
-- * Trademark of International Business Machines                         
------------------------------------------------------------------------

--**********************************************************************
--**********************************************************************
--**
--**  Product Name:      DB2 Net Search Extender
--**
--**  Source File Name:  ctectbl.ddl
--**
--**  Description:       The following script is executed
--**                     when a database is enabled for text.
--**
--**  Status:            Version 8.1.2
--**
--**********************************************************************
--**********************************************************************

--*---------------------------------------------------------------------
--* create administration table(s) per index (used for design documentation)
--*---------------------------------------------------------------------
-- CREATE TABLE
-- DB2EXT."TLOGIX123456"
--   (
--                                     -- operation code: 
--    "OPERATION"         INTEGER NOT NULL,
--                                     -- date-time of the log item:
--    "TIME"              TIMESTAMP NOT NULL,
--                                     -- primary key column 1:
--    "PK01"              <PrimaryKeyType>
--                                     -- primary key column 14:
--    "PK14"              <PrimaryKeyType>
--   )
--   PARTITIONING KEY (<subset of PK01,..,PK14 according to user table>);

------------------------------------------------------------------------

-- CREATE TABLE
-- DB2EXT."TEVENTIX123456"
--   (
--                                     -- operation code: 
--    "OPERATION"         INTEGER,
--                                     -- date-time of the event item:
--    "TIME"              TIMESTAMP,
--                                     -- severity class:
--    "SEVERITY"          INTEGER,
--                                     -- reason code:
--    "REASON"            INTEGER,
--                                     -- event message:
--    "MESSAGE"           VARCHAR(1024),
--                                     -- partition where the event occured:
--    "PARTITION"         INTEGER,
--                                     -- primary key:
--    "PK01"              <PrimaryKeyType>
--                                     -- primary key column 14:
--    "PK14"              <PrimaryKeyType>
--   )
--   PARTITIONING KEY (<subset of PK01,..,PK14 according to user table>);
--
--*---------------------------------------------------------------------
--* create administration table(s)
--*---------------------------------------------------------------------
CREATE TABLE
DB2EXT."TDBDEFAULTS"
     (
--                                     -- name of the default item:
      "NAME"              VARCHAR(30)               NOT NULL,
--                                     -- (constraint "DbDefaultsIx0" unique)
--                                     -- value of the default item:
      "VALUE"             VARCHAR(512)              NOT NULL,
--                                     -- attribute of the item:
--                                     -- <value > 0 ==> item is part of the view>
      "TYPE"              INTEGER                   NOT NULL
     );

------------------------------------------------------------------------

CREATE TABLE
DB2EXT."TTEXTINDEXES"
     (
--                                     -- identifier of the text index:
--                                     -- (used as 'index name' for the index file(s))
      "INDEXIDENTIFIER"   VARCHAR(18)               NOT NULL,
--                                     -- name of the text index:
      "INDEXSCHEMA"       VARCHAR(128)              NOT NULL,
--                                     -- schema of the text index:
      "INDEXNAME"         VARCHAR(128)              NOT NULL,
--                                     -- directory of the text index file(s):
      "INDEXDIRECTORY"    VARCHAR(256)              NOT NULL,
--                                     -- work directory for the text index:
      "WORKDIRECTORY"     VARCHAR(256)              NOT NULL,
--                                     -- maximum length of the key in user table
      "MAXIMUMKEYLENGTH"  INTEGER                   NOT NULL,
--                                     -- schema of the index log table:
      "LOGTABLESCHEMA"    VARCHAR(128),
--                                     -- name of the text index log table:
      "LOGTABLENAME"      VARCHAR(128),
--                                     -- schema of the text index log view:
      "LOGVIEWSCHEMA"     VARCHAR(128),
--                                     -- name of the text index log view:
      "LOGVIEWNAME"       VARCHAR(128),
--                                     -- schema of the text index event table:
      "EVENTTABLESCHEMA"  VARCHAR(128)              NOT NULL,
--                                     -- name of the text index event table:
      "EVENTTABLENAME"    VARCHAR(128)              NOT NULL,
--                                     -- schema of the text index event view:
      "EVENTVIEWSCHEMA"   VARCHAR(128)              NOT NULL,
--                                     -- name of the text index event view:
      "EVENTVIEWNAME"     VARCHAR(128)              NOT NULL,
--                                     -- minimum change(s) for automatic update:
      "UPDATEMINIMUM"     INTEGER,
--                                     -- update frequency information:
      "UPDATEFREQUENCY"   VARCHAR(300)              NOT NULL,
--                                     -- commit count for update index:
      "COMMITCOUNT"       INTEGER,
--                                     -- mode for update index:
--                                     -- <0 ==> initial update to be done>
--                                     -- <1 ==> incremental update to be done>
      "UPDATEMODE"        INTEGER                   NOT NULL,
--                                     -- mode for reorganization of index:
--                                     -- <0 ==> automatic
--                                     -- <1 ==> manual
      "REORGANIZATIONMODE" INTEGER,
--                                     -- index configuration signature:
--                                     -- to quickly check for identical configurations
      "CONFIGURATION"     VARCHAR(1024)             NOT NULL,
--                                     -- time index was created:
      "CREATIONTIME"      TIMESTAMP                 NOT NULL 
                                                    WITH DEFAULT CURRENT TIMESTAMP,
--                                     -- time index was last updated:
      "UPDATETIME"        TIMESTAMP                 NOT NULL 
                                                    WITH DEFAULT CURRENT TIMESTAMP,
--                                     -- expressionlists in format:       
--                                     -- A0'0attributesA0'1
--                                     -- R0'0resultsR0'1
--                                     -- S0'0sortorderS0'1
--                                     -- V0'0viewkeycolumnsV0'1
      "EXPRESSIONLISTS"   CLOB(32K)                 NOT NULL,
--                                     -- number of expressions in each list
--                                     -- of EXPRESSIONLISTS in format:       
--                                     -- number of attributes (2 Bytes) 
--                                     -- number of results (2 Bytes)
--                                     -- number of sortorder expr. (2 Bytes)
--                                     -- number of view key columns (2 Bytes)
--                                     -- high-order byte of INTEGERs first !
      "EXPRESSIONNUMBERS" VARCHAR(32) FOR BIT DATA  NOT NULL,
--                                     -- indicates if index is cacheable:
--                                     -- <0 ==> not cacheable
--                                     -- <1 ==> cacheable
      "CACHEOPTION"       INTEGER                   NOT NULL,
--                                     -- maximum size of the cached result table
      "CACHEMAXIMUM"      INTEGER,
--                                     -- percentage of the cache to be held free
      "CACHEFREE"         INTEGER, 
--                                     -- directory a persistant cache is stored in.
--                                     -- (null value => cache is temporary)
      "CACHEDIRECTORY"    VARCHAR(256),
--                                     -- directory a persistant cache is stored in.
--                                     -- for views only: primary key equivalents:
--                                     --  
--                                     --  local schema of capture control tables
--                                     --  for replication:
      "LOCALCONTROLSCHEMA" VARCHAR(128),
--                                     -- 
      CONSTRAINT "TEXTINDEXESIX0"
      PRIMARY KEY ("INDEXIDENTIFIER")
--    CONSTRAINT "TEXTINDEXESIX1"
--    UNIQUE ("INDEXSCHEMA","INDEXNAME")
     );

------------------------------------------------------------------------

CREATE TABLE
DB2EXT."TTEXTCOLUMNS"
     (
--                                     -- identifier of the text index:
      "INDEXIDENTIFIER"   VARCHAR(18)               NOT NULL,
--                                     -- schema of the text table:
--                                        (base, nickname or view)
      "TABLESCHEMA"       VARCHAR(128)              NOT NULL,
--                                     -- name of the text table:
--                                        (base, nickname or view)
      "TABLENAME"         VARCHAR(128)              NOT NULL,
--                                     -- schema of the alias:
--                                        (equal to tableschema for
--                                         base table, nickname, view)
      "ALIASSCHEMA"       VARCHAR(128)              NOT NULL,
--                                     -- name of the alias:
--                                        (equal to tablesname for
--                                         base table, nickname, view)
      "ALIASNAME"         VARCHAR(128)              NOT NULL,
--                                     -- type of the text table:
--                                     -- <T ==> regular table
--                                     -- <N ==> nickname table
--                                     -- <V ==> view
      "TABLETYPE"         CHAR(1)                   NOT NULL,
--                                     -- name of the text column:
      "COLUMNNAME"        VARCHAR(128)              NOT NULL,
--                                     -- indicates if index is used by DB2
--                                     -- <0 ==> not used by rewriter
--                                     -- <1 ==> used by rewriter
      "ACTIVEFLAG"        INTEGER                   NOT NULL,
--                                     -- schema of the type transformation function:
      "FUNCTIONSCHEMA"    VARCHAR(128),
--                                     -- name of the type transformation function:
      "FUNCTIONNAME"      VARCHAR(18),
--                                     -- text information:
      "CCSID"             INTEGER                   NOT NULL,
      "LANGUAGE"          VARCHAR(5)                NOT NULL,
      "FORMAT"            INTEGER                   NOT NULL,
--                                     -- redundant index properties from TextIndexes:
--                                     -- IndexDirectory WorkDirectory MaximumPrimaryKey
--                                     -- PreferredNode NumberOfNodes
--                                     -- each "string" value preceeded by two bytes length
      "INDEXPROPERTIES"   VARCHAR(1024) FOR BIT DATA NOT NULL, 
--                                     --
      CONSTRAINT "TEXTCOLUMNSIX0"
      FOREIGN KEY ("INDEXIDENTIFIER")
      REFERENCES DB2EXT."TTEXTINDEXES" ON DELETE CASCADE
     )
     PARTITIONING KEY ("TABLESCHEMA","TABLENAME","COLUMNNAME");

------------------------------------------------------------------------

CREATE INDEX
DB2EXT."TEXTCOLUMNSIX1" ON DB2EXT."TTEXTCOLUMNS"
     ("INDEXIDENTIFIER"  ASC);
CREATE INDEX
DB2EXT."TEXTCOLUMNSIX2" ON DB2EXT."TTEXTCOLUMNS"
     ("TABLESCHEMA","TABLENAME","COLUMNNAME"  ASC);

------------------------------------------------------------------------

CREATE TABLE
DB2EXT."TFORMATS"
     (
--                                     -- identifier of the text document format:
      "SOURCEIDENTIFIER"  INTEGER                     NOT NULL,
--                                     -- (constraint "FormatsIx0" unique)
--                                     -- name of the text document format:
      "SOURCENAME"        VARCHAR(30)                 NOT NULL,
--                                     -- (constraint "FormatsIx1" unique)
--                                     -- identifier of the format after transformation:
      "TARGETIDENTIFIER"  INTEGER,                       
--                                     -- schema of the format transformation function:
--                                        (null for predefined supported format(s))
      "FUNCTIONSCHEMA"    VARCHAR(128),
--                                     -- name of the format transformation function:
--                                        (null for predefined supported format(s))
      "FUNCTIONNAME"      VARCHAR(18)
     );

------------------------------------------------------------------------

CREATE TABLE
DB2EXT."TMODELS"
     (
--                                     -- name of the document model:
      "MODELNAME"         VARCHAR(30)               NOT NULL,
--                                     -- identifier of the document format:
      "FORMATIDENTIFIER"  INTEGER                   NOT NULL,
--                                     -- identifier of the text index:
      "INDEXIDENTIFIER"   VARCHAR(18)               NOT NULL,
--                                     -- sequence number (0 <==> default model)
      "MODELNUMBER"       INTEGER                   NOT NULL,
--                                     -- CCSID of model file:
      "CCSID"             INTEGER                   NOT NULL,
--                                     -- path-name of model file:
      "MODELFILE"         VARCHAR(256)              NOT NULL,
--                                     --
      CONSTRAINT "MODELSIX0"
      PRIMARY KEY ("MODELNAME","FORMATIDENTIFIER","INDEXIDENTIFIER"),
      CONSTRAINT "MODELSFK0"
      FOREIGN KEY ("INDEXIDENTIFIER")
      REFERENCES DB2EXT."TTEXTINDEXES" ON DELETE CASCADE
     );

------------------------------------------------------------------------

CREATE TABLE
DB2EXT."TCOMMANDLOCKS"
     (
--                                     -- identifier for the command:
--                                     -- DISABLE (2), CREATE (7), 
--                                     -- DROP (8), UPDATE (9),
--                                     -- ALTER (11), CLEAR (12), 
--                                     -- ACTIVATE (17), DEACTIVATE (18))
      "COMMANDIDENTIFIER" INTEGER                   NOT NULL,
--                                     -- identifier of the text index:
--                                        if lockscope == 0
      "INDEXIDENTIFIER"   VARCHAR(18)               NOT NULL,
--                                     -- scope of the lock:
--                                     -- INDEX(0), DATABASE(1)
      "LOCKSCOPE"         INTEGER                   NOT NULL,
--                                     -- process identifier of requestor:
      "PROCESSIDENTIFIER" INTEGER                   NOT NULL,
--                                     -- thread identifier of requestor:
      "THREADIDENTIFIER"  INTEGER                   NOT NULL,
--                                     -- node the requestor was running on:
      "NODENUMBER"        INTEGER                   NOT NULL,
--                                     -- time the lock was requested:
      "LOCKTIME"          TIMESTAMP                 NOT NULL,
--                                     --
      CONSTRAINT "COMMANDLOCKSIX0"
      PRIMARY KEY ("LOCKSCOPE", "INDEXIDENTIFIER")
     );

------------------------------------------------------------------------

CREATE TABLE
DB2EXT."TCONFIGURATION"
     (
--                                     -- identifier of the text index:
      "INDEXIDENTIFIER"   VARCHAR(18)               NOT NULL,
--                                     -- configuration parameter name:
      "PARAMETER"         VARCHAR(30)               NOT NULL,
--                                     -- configuration parameter value:
      "VALUE"             VARCHAR(512)              NOT NULL,
--
      CONSTRAINT "CONFIGURATIONFK0"
      FOREIGN KEY ("INDEXIDENTIFIER")
      REFERENCES DB2EXT."TTEXTINDEXES" ON DELETE CASCADE
     );

------------------------------------------------------------------------

CREATE INDEX
DB2EXT."TCONFIGURATIONIX1" ON DB2EXT."TCONFIGURATION"
     ("INDEXIDENTIFIER"  ASC);

------------------------------------------------------------------------

CREATE TABLE
DB2EXT."TTEXTREPLICATION"
     (
--                                        -- identifier of the text index:
      "INDEXIDENTIFIER"      VARCHAR(18)               NOT NULL,
--                                        -- remote schema of source table:
      "REMOTESOURCETABLESCHEMA" VARCHAR(128)           NOT NULL,
--                                        -- name of remote source table:
      "REMOTESOURCETABLENAME"   VARCHAR(128)           NOT NULL,
--                                        -- remote schema of capture table:
      "REMOTECAPTABLESCHEMA" VARCHAR(128)              NOT NULL,
--                                        -- name of remote capture table:
      "REMOTECAPTABLENAME"   VARCHAR(128)              NOT NULL,
--                                        -- name of federated server:
      "SERVERNAME"           VARCHAR(128)              NOT NULL,
--                                        -- type of federated server:
      "SERVERTYPE"           VARCHAR(30)               NOT NULL,
--                                        -- version of federated server:
      "SERVERVERSION"        VARCHAR(18)               NOT NULL,
--                                        -- 
      CONSTRAINT "TEXTREPLICATIONIX0"
      FOREIGN KEY ("INDEXIDENTIFIER")
      REFERENCES DB2EXT."TTEXTINDEXES" ON DELETE CASCADE
     );

------------------------------------------------------------------------

--*---------------------------------------------------------------------
--* grant privilege(s) on administration table(s)
--*---------------------------------------------------------------------
GRANT SELECT ON TABLE  DB2EXT."TDBDEFAULTS"      TO PUBLIC;
GRANT SELECT ON TABLE  DB2EXT."TTEXTINDEXES"     TO PUBLIC;
GRANT SELECT ON TABLE  DB2EXT."TTEXTCOLUMNS"     TO PUBLIC;
GRANT SELECT ON TABLE  DB2EXT."TFORMATS"         TO PUBLIC;
GRANT SELECT ON TABLE  DB2EXT."TMODELS"          TO PUBLIC;
GRANT SELECT ON TABLE  DB2EXT."TCOMMANDLOCKS"    TO PUBLIC;
GRANT SELECT ON TABLE  DB2EXT."TCONFIGURATION"   TO PUBLIC;
GRANT SELECT ON TABLE  DB2EXT."TTEXTREPLICATION" TO PUBLIC;

------------------------------------------------------------------------

