
------------------------------------------------------------------------
--  IBM*                                                                  
--  Licensed Materials - Property of IBM                                  
--  5765-F38                                                              
--  (C) Copyright IBM Corporation 2001,2003                               
--  All rights reserved.                                                  
--                                                                        
-- * Trademark of International Business Machines                         
------------------------------------------------------------------------

--**********************************************************************
--**********************************************************************
--**
--**  Product Name:      DB2 Net Search Extender
--**
--**  Source File Name:  ctectrig.ddl
--**
--**  Description:       The following script is executed
--**                     when a database is enabled for text.
--**
--**  Status:            Version 8.1.2
--**
--**********************************************************************
--**********************************************************************

--*---------------------------------------------------------------------
--* The following trigger ensures, that after dropping an active text
--* index, an equivalent inactive index is marked correctly as active:
--* Note, that this requires to delete the 
--* DB2EXT.TTEXTINDEXES row first for the index !
--*---------------------------------------------------------------------
CREATE TRIGGER DB2EXT.TTCDEL 
AFTER DELETE ON DB2EXT.TTEXTCOLUMNS
REFERENCING OLD AS O
FOR EACH ROW MODE DB2SQL
WHEN (O.ACTIVEFLAG=1)
  UPDATE DB2EXT.TTEXTCOLUMNS SET ACTIVEFLAG=1 
  WHERE O.TABLESCHEMA=TABLESCHEMA AND
        O.TABLENAME=TABLENAME     AND
        O.COLUMNNAME=COLUMNNAME   AND
        INDEXIDENTIFIER=(SELECT INDEXIDENTIFIER
               FROM DB2EXT.TTEXTINDEXES			
               WHERE UPDATETIME=
                            (SELECT MAX(UPDATETIME) 
                             FROM DB2EXT.TTEXTINDEXES TI, 
                                  DB2EXT.TTEXTCOLUMNS TC
                             WHERE O.TABLESCHEMA=TC.TABLESCHEMA AND
                                   O.TABLENAME=TC.TABLENAME     AND
                                   O.COLUMNNAME=TC.COLUMNNAME   AND
                                   TC.TABLETYPE IN ('T','N')    AND
                                   TC.INDEXIDENTIFIER=TI.INDEXIDENTIFIER
                            )
               )
;

--*---------------------------------------------------------------------
--* The following trigger ensures, that newly created text indexes on 
--* table/nickname/view are marked correctly as active/inactive:
--*---------------------------------------------------------------------
CREATE TRIGGER DB2EXT.TTCINS 
NO CASCADE BEFORE INSERT ON DB2EXT.TTEXTCOLUMNS 
REFERENCING NEW AS N
FOR EACH ROW MODE DB2SQL
  SET N.ACTIVEFLAG=CASE WHEN TABLETYPE IN ('T','N')
                   THEN (SELECT CASE WHEN COUNT(*)=0 THEN 1 ELSE 0 END
                         FROM DB2EXT.TTEXTCOLUMNS
                         WHERE N.TABLESCHEMA=TABLESCHEMA AND
                               N.TABLENAME=TABLENAME     AND
                               N.COLUMNNAME=COLUMNNAME   AND
                               ACTIVEFLAG=1)
                   ELSE 0
                   END
;

------------------------------------------------------------------------

